AsmOperand

Enum AsmOperand 

pub enum AsmOperand {
    In {
        reg: AsmRegister,
        value: Operand,
    },
    Out {
        reg: AsmRegister,
        late: bool,
        place: Option<Place>,
    },
    InOut {
        reg: AsmRegister,
        late: bool,
        in_value: Operand,
        out_place: Option<Place>,
    },
    Const(ConstantExpr),
    SymFn(FnPtr),
    SymStatic(GlobalDeclRef),
    Label(BranchId),
}
An operand supplied to inline assembly.

Variants



In

in(reg) value: read value into the register before running the assembly.

Fields

value: Operand


Out

out(reg) place or lateout(reg) place: the contents of the register are written to place at the end of the block, or discarded if place is None (essentially acting as a clobber).

Fields

late: bool
place: Option<Place>


InOut

inout(reg) value => place or inlateout(reg) value => place. Combines in(reg) value and out/lateout(reg) place. The input and output places may be the same.

Fields

late: bool
in_value: Operand
out_place: Option<Place>


Const(ConstantExpr)

An integer constant substituted into the template.



SymFn(FnPtr)

A function symbol substituted into the template.



SymStatic(GlobalDeclRef)

A static symbol substituted into the template.



Label(BranchId)

The address of a block that the assembly may jump to. That BranchId corresponds to the targets listed in ullbc_ast::TerminatorKind::InlineAsm and llbc_ast::StatementKind::InlineAsm.