AsmOptions

Struct AsmOptions 

pub struct AsmOptions {
    pub pure: bool,
    pub nomem: bool,
    pub readonly: bool,
    pub preserves_flags: bool,
    pub noreturn: bool,
    pub nostack: bool,
    pub att_syntax: bool,
    pub may_unwind: bool,
}
The flags set in options(...). These flags constrain the assembly’s effects; they do not describe instructions in the template itself.

Fields

pure: bool

The assembly code has no side effects, must eventually return, and its outputs depend only on its direct inputs or values read from memory.

nomem: bool

The assembly code does not read from or write to any memory accessible outside of the assembly code.

readonly: bool

The assembly code does not write to any memory accessible outside of the assembly code.

preserves_flags: bool

The assembly code does not modify the flags register.

noreturn: bool

The assembly code does not fall through; it may still jump to label blocks.

nostack: bool

The assembly code does not push data to the stack, or write to the stack red-zone.

att_syntax: bool

Only valid on x86; causes the assembler to use the .att_syntax prefix mode of the GNU assembler.

may_unwind: bool

Allows unwinding out of an asm! block (unstable, see https://github.com/rust-lang/rust/issues/93334). naked_asm! may unwind regardless of this option.